@@ -5,6 +5,17 @@ use warnings;
 use base 'App::Ack::Filter';
 
 use File::Spec 3.00;
+use App::Ack::Filter::MatchGroup ();
+
+=head1 NAME
+
+App::Ack::Filter::Match
+
+=head1 DESCRIPTION
+
+Implements filtering resources by their filename (regular expression).
+
+=cut
 
 sub new {
     my ( $class, $re ) = @_;
@@ -14,16 +25,20 @@ sub new {
 
     return bless {
         regex => $re,
+        groupname => 'MatchGroup',
     }, $class;
 }
 
+sub create_group {
+    return App::Ack::Filter::MatchGroup->new;
+}
+
 sub filter {
     my ( $self, $resource ) = @_;
 
-    my $re   = $self->{'regex'};
-    my $base = (File::Spec->splitpath($resource->name))[2];
+    my $re = $self->{'regex'};
 
-    return $base =~ /$re/;
+    return $resource->basename =~ /$re/;
 }
 
 sub inspect {
@@ -32,6 +47,8 @@ sub inspect {
     my $re = $self->{'regex'};
 
     print ref($self) . " - $re";
+
+    return;
 }
 
 sub to_string {
